@@ -7,9 +7,41 @@
 # @Date   :  2020-11-05 10:23:57
 # @Description :  一系列统计学相关的计算函数
 
+from collections import Counter
+
 import numpy as np
 
-__version__ = "0.2.2"
+__version__ = "0.3.0"
+
+
+def calculate_list_count_percent(data: list, decimals: None or int = None):
+    """计算list中元素的次数和百分比
+
+    Args:
+        data (list): list类型数据。
+        decimals (None or int): 保留的小数位数，默认为None，则不进行位数操作；
+            如果>=0，则保留相应的小数位数。
+
+    Returns:
+        tuple: 元组第一个元素为次数统计结果，第二个元素为百分比统计结果。
+
+    """
+    counter = dict(Counter(data))
+
+    total_count = sum(list(counter.values()))
+
+    percenter = dict(
+        [
+            (
+                key,
+                value / total_count
+                if decimals is None
+                else round(value / total_count, decimals),
+            )
+            for key, value in counter.items()
+        ]
+    )
+    return counter, percenter
 
 
 def smooth_ma(data: list or np.array, window_size=3):
@@ -17,11 +49,11 @@ def smooth_ma(data: list or np.array, window_size=3):
     平滑后的数组的长度为：len(data) - window_size + 1
 
     Args:
-        data(list or np.array): 原始数组。
-        window_size(int): 窗口大小。
+        data (list or np.array): 原始数组。
+        window_size (int): 窗口大小。
 
     Returns:
-        (np.array): 平滑后的数组
+        np.array: 平滑后的数组
     """
     cumsum_vec = np.cumsum(np.insert(data, 0, 0))
     ma_vec = (cumsum_vec[window_size:] - cumsum_vec[:-window_size]) / window_size
@@ -34,11 +66,11 @@ def smooth_matlab(data: list or np.array, window_size: int = 3):
     平滑后的数组的长度为：len(data)
 
     Args:
-        data(list or np.array): 原始数组。
-        window_size(int): 窗口大小。
+        data (list or np.array): 原始数组。
+        window_size (int): 窗口大小。
 
     Returns:
-        (np.array): 平滑后的数组
+        np.array: 平滑后的数组
 
     """
 
@@ -58,8 +90,8 @@ def normalization(data: list or np.array, decimals: None or int = None):
 
     Args:
 
-        data(list or np.array): 需要被归一化的数据。
-        decimals(None or int): 归一化后，数值保留的精度（小数位数），默认为None，不开启
+        data (list or np.array): 需要被归一化的数据。
+        decimals (None or int): 归一化后，数值保留的精度（小数位数），默认为None，不开启
 
     Returns:
         np.array: 处理后的数据
@@ -75,8 +107,8 @@ def standardization(data: list or np.array, decimals: None or int = None):
 
     Args:
 
-        data(list or np.array): 需要被标准化的数据。
-        decimals(None or int): 归一化后，数值保留的精度（小数位数），默认为None，不开启
+        data (list or np.array): 需要被标准化的数据。
+        decimals (None or int): 归一化后，数值保留的精度（小数位数），默认为None，不开启
 
     Returns:
         np.array: 处理后的数据
@@ -93,8 +125,8 @@ def zero_centered(data: list or np.array, decimals: None or int = None):
 
     Args:
 
-        data(list or np.array): 需要被零均值化的数据。
-        decimals(None or int): 数值保留的精度（小数位数），默认为None，不开启
+        data (list or np.array): 需要被零均值化的数据。
+        decimals (None or int): 数值保留的精度（小数位数），默认为None，不开启
 
     Returns:
         np.array: 处理后的数据
